==> zio-aws-appmesh_3-5.17.104.3-sources.jar: zio/aws/appmesh/model/DescribeGatewayRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class DescribeGatewayRouteRequest(
    gatewayRouteName: ResourceName,
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    virtualGatewayName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest = {
    import DescribeGatewayRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
      .builder()
      .gatewayRouteName(ResourceName.unwrap(gatewayRouteName): java.lang.String)
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .virtualGatewayName(
        ResourceName.unwrap(virtualGatewayName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly =
    zio.aws.appmesh.model.DescribeGatewayRouteRequest.wrap(buildAwsValue())
}
object DescribeGatewayRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DescribeGatewayRouteRequest =
      zio.aws.appmesh.model.DescribeGatewayRouteRequest(
        gatewayRouteName,
        meshName,
        meshOwner.map(value => value),
        virtualGatewayName
      )
    def gatewayRouteName: ResourceName
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def virtualGatewayName: ResourceName
    def getGatewayRouteName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(gatewayRouteName)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getVirtualGatewayName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualGatewayName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ) extends zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly {
    override val gatewayRouteName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.gatewayRouteName())
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val virtualGatewayName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualGatewayName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ): zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-appmesh_3-5.17.170.1-sources.jar: zio/aws/appmesh/model/DescribeGatewayRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class DescribeGatewayRouteRequest(
    gatewayRouteName: ResourceName,
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    virtualGatewayName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest = {
    import DescribeGatewayRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
      .builder()
      .gatewayRouteName(ResourceName.unwrap(gatewayRouteName): java.lang.String)
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .virtualGatewayName(
        ResourceName.unwrap(virtualGatewayName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly =
    zio.aws.appmesh.model.DescribeGatewayRouteRequest.wrap(buildAwsValue())
}
object DescribeGatewayRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.DescribeGatewayRouteRequest =
      zio.aws.appmesh.model.DescribeGatewayRouteRequest(
        gatewayRouteName,
        meshName,
        meshOwner.map(value => value),
        virtualGatewayName
      )
    def gatewayRouteName: ResourceName
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def virtualGatewayName: ResourceName
    def getGatewayRouteName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(gatewayRouteName)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getVirtualGatewayName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualGatewayName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ) extends zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly {
    override val gatewayRouteName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.gatewayRouteName())
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val virtualGatewayName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualGatewayName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.DescribeGatewayRouteRequest
  ): zio.aws.appmesh.model.DescribeGatewayRouteRequest.ReadOnly = new Wrapper(
    impl
  )
}
